@@ -165,7 +165,10 @@ def test_openapi_schema(client: TestClient):
                             "files": {
                                 "title": "Files",
                                 "type": "array",
-                                "items": {"type": "string", "format": "binary"},
+                                "items": {
+                                    "type": "string",
+                                    "contentMediaType": "application/octet-stream",
+                                },
                                 "description": "Multiple files as bytes",
                             }
                         },
@@ -178,7 +181,10 @@ def test_openapi_schema(client: TestClient):
                             "files": {
                                 "title": "Files",
                                 "type": "array",
-                                "items": {"type": "string", "format": "binary"},
+                                "items": {
+                                    "type": "string",
+                                    "contentMediaType": "application/octet-stream",
+                                },
                                 "description": "Multiple files as UploadFile",
                             }
                         },
